==> Geo-MapInfo-MIF-Writer-Region-0.03.tar.gz: Geo-MapInfo-MIF-Writer-Region-0.03/scripts/perl-Geo-MapInfo-MIF-Writer-Region-mrdvt92.pl <==
#!/user/bin/perl
use strict;
use warnings;
use Geo::MapInfo::MIF::Writer::Region;

=head1 NAME

perl-Geo-MapInfo-MIF-Writer-Region-mrdvt92.pl - Geo::MapInfo::MIF::Writer::Region Simple Exmaple

=cut

my $map=Geo::MapInfo::MIF::Writer::Region->new(basename=>"mrdvt92");

$map->addSimpleRegion(region=>[&m]);
$map->addMultipartRegion(regions=>[[&r1],[&r2]]);
$map->addMultipartRegion(regions=>[[&d1],[&d2]]);
$map->save;


sub m {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.266335 38.822397
-77.281014 38.915709
-77.30849 38.847924
-77.308886 38.847098
-77.309388 38.846323
-77.309985 38.845616
-77.31067 38.844983
-77.311432 38.844435
-77.312261 38.843978
-77.313141 38.843622
-77.31406 38.843373
-77.315004 38.84323
-77.315959 38.843203
-77.316912 38.843283
-77.317848 38.843475
-77.318751 38.843774
-77.319607 38.844176
-77.320406 38.844677
-77.321136 38.845264
-77.32178 38.845934
-77.322335 38.846672
-77.32279 38.847473
-77.323136 38.848318
-77.323193 38.848488
-77.343289 38.913322
-77.367152 38.812837
-77.367419 38.811965
-77.367799 38.811131
-77.368281 38.81035
-77.368862 38.809626
-77.369533 38.80898
-77.37028 38.808414
-77.371097 38.807942
-77.371969 38.807569
-77.372881 38.8073
-77.373823 38.807135
-77.374778 38.807085
-77.375732 38.807148
-77.376672 38.80732
-77.377581 38.807598
-77.378449 38.807984
-77.379258 38.808468
-77.379999 38.809042
-77.380661 38.809695
-77.381234 38.810424
-77.381707 38.811211
-77.382075 38.812048
-77.382331 38.812924
-77.382471 38.813821
-77.382494 38.814729
-77.3824 38.815631
-77.382309 38.816077
-77.351864 38.944279
-77.351597 38.945152
-77.351217 38.945985
-77.350736 38.946767
-77.350154 38.94749
-77.349484 38.948137
-77.348736 38.948702
-77.347918 38.949174
-77.347047 38.949548
-77.346135 38.949818
-77.345194 38.949981
-77.344238 38.950032
-77.343284 38.949969
-77.342344 38.949798
-77.341435 38.949517
-77.340568 38.949132
-77.339759 38.948649
-77.339017 38.948076
-77.338354 38.947423
-77.337783 38.946693
-77.33731 38.945905
-77.336941 38.945069
-77.336832 38.944739
-77.314757 38.873528
-77.284932 38.947111
-77.284535 38.947936
-77.284034 38.94871
-77.283436 38.949418
-77.28275 38.950052
-77.281988 38.950601
-77.28116 38.951056
-77.280281 38.951413
-77.279361 38.951662
-77.278417 38.951805
-77.277462 38.951832
-77.276509 38.951752
-77.275572 38.95156
-77.274671 38.951259
-77.273813 38.950857
-77.273016 38.950358
-77.272286 38.94977
-77.27164 38.949099
-77.271087 38.948362
-77.270632 38.947561
-77.270283 38.946717
-77.270048 38.945838
-77.269998 38.945552
-77.250968 38.824573
-77.250885 38.82367
-77.25092 38.822762
-77.251073 38.821867
-77.25134 38.820994
-77.251719 38.820162
-77.252201 38.819379
-77.252783 38.818657
-77.253451 38.818007
-77.2542 38.817444
-77.255016 38.816971
-77.255887 38.816598
-77.2568 38.816326
-77.257743 38.816164
-77.258698 38.816113
-77.25965 38.816174
-77.26059 38.816347
-77.2615 38.816628
-77.262367 38.817012
-77.263177 38.817493
-77.263919 38.818067
-77.264579 38.818723
-77.265152 38.81945
-77.265627 38.820239
-77.265994 38.821076
-77.26625 38.82195
-77.266335 38.822397};
}


sub r1 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.213138 38.834227
-77.213128 38.834682
-77.207419 38.944826
-77.207313 38.945728
-77.207093 38.946612
-77.206759 38.947462
-77.206314 38.948267
-77.205772 38.949013
-77.205136 38.949693
-77.204418 38.950292
-77.203629 38.950804
-77.202778 38.951215
-77.201879 38.951529
-77.200947 38.951736
-77.199996 38.95183
-77.199039 38.951811
-77.198093 38.951686
-77.19767 38.95159
-77.140668 38.937265
-77.139761 38.93698
-77.138897 38.93659
-77.138091 38.936105
-77.137352 38.935526
-77.136696 38.934867
-77.136127 38.934136
-77.135659 38.933344
-77.13552 38.933051
-77.124015 38.907651
-77.123694 38.906798
-77.123482 38.90591
-77.12339 38.905007
-77.123413 38.904101
-77.123556 38.903202
-77.123812 38.902329
-77.12418 38.901489
-77.124653 38.9007
-77.125225 38.899975
-77.125887 38.89932
-77.126628 38.898747
-77.12744 38.898262
-77.12823 38.897909
-77.178062 38.8787
-77.131468 38.83601
-77.130821 38.835343
-77.130266 38.834601
-77.129813 38.833802
-77.129464 38.832957
-77.129231 38.832078
-77.129112 38.831177
-77.12911 38.83027
-77.129223 38.829369
-77.129456 38.828487
-77.129798 38.827643
-77.130249 38.82684
-77.1308 38.826099
-77.131443 38.825426
-77.132168 38.824835
-77.132964 38.824331
-77.133819 38.823926
-77.134722 38.823622
-77.135655 38.823427
-77.136609 38.82334
-77.137563 38.823366
-77.13851 38.823504
-77.139429 38.82375
-77.14031 38.824102
-77.141141 38.824556
-77.141905 38.8251
-77.142259 38.825406
-77.195523 38.874206
-77.19761 38.833958
-77.197715 38.833056
-77.197936 38.832172
-77.19827 38.831322
-77.198714 38.830516
-77.199257 38.829771
-77.199892 38.829091
-77.20061 38.828492
-77.2014 38.82798
-77.20225 38.827569
-77.20315 38.827255
-77.204082 38.827048
-77.205032 38.826954
-77.205989 38.826972
-77.206936 38.827098
-77.20786 38.827337
-77.208746 38.82768
-77.209579 38.828123
-77.21035 38.828663
-77.211044 38.829283
-77.211654 38.829985
-77.212166 38.830752
-77.212578 38.831571
-77.212879 38.832432
-77.213066 38.833324
-77.213138 38.834227};
}

sub r2 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.1948 38.888164
-77.141421 38.908739
-77.148301 38.923935
-77.192372 38.935006
-77.1948 38.888164};
}

sub d1 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.089443 38.944337
-77.089402 38.945243
-77.089243 38.946141
-77.088969 38.947009
-77.088582 38.947839
-77.088094 38.948619
-77.087507 38.949336
-77.086832 38.949978
-77.086079 38.950539
-77.085259 38.951008
-77.084385 38.951375
-77.083469 38.951639
-77.082528 38.951793
-77.081572 38.951835
-77.080617 38.951769
-77.07968 38.951587
-77.078773 38.951303
-77.078567 38.951221
-77.019561 38.926776
-77.018711 38.92636
-77.01792 38.925851
-77.017201 38.925252
-77.016563 38.924576
-77.016019 38.923828
-77.015577 38.923025
-77.015243 38.922174
-77.015018 38.921292
-77.014912 38.920392
-77.014904 38.920173
-77.013836 38.871087
-77.013834 38.870868
-77.013886 38.870184
-77.013876 38.87018
-77.013895 38.870072
-77.013903 38.869962
-77.013972 38.869623
-77.014031 38.869285
-77.014063 38.86918
-77.014087 38.869071
-77.014199 38.868744
-77.014302 38.868413
-77.014348 38.868314
-77.014386 38.86821
-77.01454 38.867896
-77.014685 38.867581
-77.014743 38.867487
-77.014793 38.867388
-77.014985 38.867097
-77.015171 38.866802
-77.015243 38.866716
-77.015303 38.866621
-77.015533 38.866353
-77.015754 38.86608
-77.015836 38.866005
-77.015909 38.865918
-77.016173 38.865682
-77.016428 38.865437
-77.01652 38.865368
-77.016603 38.865294
-77.016893 38.865087
-77.01718 38.864875
-77.017188 38.864883
-77.017373 38.864754
-77.017781 38.864518
-77.075951 38.833318
-77.07681 38.832921
-77.077714 38.832629
-77.078652 38.832443
-77.079604 38.832365
-77.080561 38.832402
-77.081505 38.832549
-77.082423 38.832807
-77.083301 38.833168
-77.084124 38.833629
-77.084883 38.834181
-77.085562 38.83482
-77.086155 38.835531
-77.086649 38.836308
-77.087043 38.837136
-77.087325 38.838005
-77.087492 38.838898
-77.08754 38.839608
-77.089443 38.944337};
}

sub d2 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.029467 38.875186
-77.030335 38.91515
-77.073701 38.933117
-77.07223 38.85225
-77.029467 38.875186};
}

==> Geo-MapInfo-MIF-Writer-Region-0.05.tar.gz: Geo-MapInfo-MIF-Writer-Region-0.05/scripts/perl-Geo-MapInfo-MIF-Writer-Region-mrdvt92.pl <==
#!/user/bin/perl
use strict;
use warnings;
use Geo::MapInfo::MIF::Writer::Region;

=head1 NAME

perl-Geo-MapInfo-MIF-Writer-Region-mrdvt92.pl - Geo::MapInfo::MIF::Writer::Region Simple Example

=cut

my $map=Geo::MapInfo::MIF::Writer::Region->new(basename=>"mrdvt92");

$map->addSimpleRegion(region=>[&m]);
$map->addMultipartRegion(regions=>[[&r1],[&r2]]);
$map->addMultipartRegion(regions=>[[&d1],[&d2]]);
$map->save;


sub m {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.266335 38.822397
-77.281014 38.915709
-77.30849 38.847924
-77.308886 38.847098
-77.309388 38.846323
-77.309985 38.845616
-77.31067 38.844983
-77.311432 38.844435
-77.312261 38.843978
-77.313141 38.843622
-77.31406 38.843373
-77.315004 38.84323
-77.315959 38.843203
-77.316912 38.843283
-77.317848 38.843475
-77.318751 38.843774
-77.319607 38.844176
-77.320406 38.844677
-77.321136 38.845264
-77.32178 38.845934
-77.322335 38.846672
-77.32279 38.847473
-77.323136 38.848318
-77.323193 38.848488
-77.343289 38.913322
-77.367152 38.812837
-77.367419 38.811965
-77.367799 38.811131
-77.368281 38.81035
-77.368862 38.809626
-77.369533 38.80898
-77.37028 38.808414
-77.371097 38.807942
-77.371969 38.807569
-77.372881 38.8073
-77.373823 38.807135
-77.374778 38.807085
-77.375732 38.807148
-77.376672 38.80732
-77.377581 38.807598
-77.378449 38.807984
-77.379258 38.808468
-77.379999 38.809042
-77.380661 38.809695
-77.381234 38.810424
-77.381707 38.811211
-77.382075 38.812048
-77.382331 38.812924
-77.382471 38.813821
-77.382494 38.814729
-77.3824 38.815631
-77.382309 38.816077
-77.351864 38.944279
-77.351597 38.945152
-77.351217 38.945985
-77.350736 38.946767
-77.350154 38.94749
-77.349484 38.948137
-77.348736 38.948702
-77.347918 38.949174
-77.347047 38.949548
-77.346135 38.949818
-77.345194 38.949981
-77.344238 38.950032
-77.343284 38.949969
-77.342344 38.949798
-77.341435 38.949517
-77.340568 38.949132
-77.339759 38.948649
-77.339017 38.948076
-77.338354 38.947423
-77.337783 38.946693
-77.33731 38.945905
-77.336941 38.945069
-77.336832 38.944739
-77.314757 38.873528
-77.284932 38.947111
-77.284535 38.947936
-77.284034 38.94871
-77.283436 38.949418
-77.28275 38.950052
-77.281988 38.950601
-77.28116 38.951056
-77.280281 38.951413
-77.279361 38.951662
-77.278417 38.951805
-77.277462 38.951832
-77.276509 38.951752
-77.275572 38.95156
-77.274671 38.951259
-77.273813 38.950857
-77.273016 38.950358
-77.272286 38.94977
-77.27164 38.949099
-77.271087 38.948362
-77.270632 38.947561
-77.270283 38.946717
-77.270048 38.945838
-77.269998 38.945552
-77.250968 38.824573
-77.250885 38.82367
-77.25092 38.822762
-77.251073 38.821867
-77.25134 38.820994
-77.251719 38.820162
-77.252201 38.819379
-77.252783 38.818657
-77.253451 38.818007
-77.2542 38.817444
-77.255016 38.816971
-77.255887 38.816598
-77.2568 38.816326
-77.257743 38.816164
-77.258698 38.816113
-77.25965 38.816174
-77.26059 38.816347
-77.2615 38.816628
-77.262367 38.817012
-77.263177 38.817493
-77.263919 38.818067
-77.264579 38.818723
-77.265152 38.81945
-77.265627 38.820239
-77.265994 38.821076
-77.26625 38.82195
-77.266335 38.822397};
}


sub r1 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.213138 38.834227
-77.213128 38.834682
-77.207419 38.944826
-77.207313 38.945728
-77.207093 38.946612
-77.206759 38.947462
-77.206314 38.948267
-77.205772 38.949013
-77.205136 38.949693
-77.204418 38.950292
-77.203629 38.950804
-77.202778 38.951215
-77.201879 38.951529
-77.200947 38.951736
-77.199996 38.95183
-77.199039 38.951811
-77.198093 38.951686
-77.19767 38.95159
-77.140668 38.937265
-77.139761 38.93698
-77.138897 38.93659
-77.138091 38.936105
-77.137352 38.935526
-77.136696 38.934867
-77.136127 38.934136
-77.135659 38.933344
-77.13552 38.933051
-77.124015 38.907651
-77.123694 38.906798
-77.123482 38.90591
-77.12339 38.905007
-77.123413 38.904101
-77.123556 38.903202
-77.123812 38.902329
-77.12418 38.901489
-77.124653 38.9007
-77.125225 38.899975
-77.125887 38.89932
-77.126628 38.898747
-77.12744 38.898262
-77.12823 38.897909
-77.178062 38.8787
-77.131468 38.83601
-77.130821 38.835343
-77.130266 38.834601
-77.129813 38.833802
-77.129464 38.832957
-77.129231 38.832078
-77.129112 38.831177
-77.12911 38.83027
-77.129223 38.829369
-77.129456 38.828487
-77.129798 38.827643
-77.130249 38.82684
-77.1308 38.826099
-77.131443 38.825426
-77.132168 38.824835
-77.132964 38.824331
-77.133819 38.823926
-77.134722 38.823622
-77.135655 38.823427
-77.136609 38.82334
-77.137563 38.823366
-77.13851 38.823504
-77.139429 38.82375
-77.14031 38.824102
-77.141141 38.824556
-77.141905 38.8251
-77.142259 38.825406
-77.195523 38.874206
-77.19761 38.833958
-77.197715 38.833056
-77.197936 38.832172
-77.19827 38.831322
-77.198714 38.830516
-77.199257 38.829771
-77.199892 38.829091
-77.20061 38.828492
-77.2014 38.82798
-77.20225 38.827569
-77.20315 38.827255
-77.204082 38.827048
-77.205032 38.826954
-77.205989 38.826972
-77.206936 38.827098
-77.20786 38.827337
-77.208746 38.82768
-77.209579 38.828123
-77.21035 38.828663
-77.211044 38.829283
-77.211654 38.829985
-77.212166 38.830752
-77.212578 38.831571
-77.212879 38.832432
-77.213066 38.833324
-77.213138 38.834227};
}

sub r2 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.1948 38.888164
-77.141421 38.908739
-77.148301 38.923935
-77.192372 38.935006
-77.1948 38.888164};
}

sub d1 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.089443 38.944337
-77.089402 38.945243
-77.089243 38.946141
-77.088969 38.947009
-77.088582 38.947839
-77.088094 38.948619
-77.087507 38.949336
-77.086832 38.949978
-77.086079 38.950539
-77.085259 38.951008
-77.084385 38.951375
-77.083469 38.951639
-77.082528 38.951793
-77.081572 38.951835
-77.080617 38.951769
-77.07968 38.951587
-77.078773 38.951303
-77.078567 38.951221
-77.019561 38.926776
-77.018711 38.92636
-77.01792 38.925851
-77.017201 38.925252
-77.016563 38.924576
-77.016019 38.923828
-77.015577 38.923025
-77.015243 38.922174
-77.015018 38.921292
-77.014912 38.920392
-77.014904 38.920173
-77.013836 38.871087
-77.013834 38.870868
-77.013886 38.870184
-77.013876 38.87018
-77.013895 38.870072
-77.013903 38.869962
-77.013972 38.869623
-77.014031 38.869285
-77.014063 38.86918
-77.014087 38.869071
-77.014199 38.868744
-77.014302 38.868413
-77.014348 38.868314
-77.014386 38.86821
-77.01454 38.867896
-77.014685 38.867581
-77.014743 38.867487
-77.014793 38.867388
-77.014985 38.867097
-77.015171 38.866802
-77.015243 38.866716
-77.015303 38.866621
-77.015533 38.866353
-77.015754 38.86608
-77.015836 38.866005
-77.015909 38.865918
-77.016173 38.865682
-77.016428 38.865437
-77.01652 38.865368
-77.016603 38.865294
-77.016893 38.865087
-77.01718 38.864875
-77.017188 38.864883
-77.017373 38.864754
-77.017781 38.864518
-77.075951 38.833318
-77.07681 38.832921
-77.077714 38.832629
-77.078652 38.832443
-77.079604 38.832365
-77.080561 38.832402
-77.081505 38.832549
-77.082423 38.832807
-77.083301 38.833168
-77.084124 38.833629
-77.084883 38.834181
-77.085562 38.83482
-77.086155 38.835531
-77.086649 38.836308
-77.087043 38.837136
-77.087325 38.838005
-77.087492 38.838898
-77.08754 38.839608
-77.089443 38.944337};
}

sub d2 {
  return map {[split /\s+/, $_]} split /\r?\n/, q{-77.029467 38.875186
-77.030335 38.91515
-77.073701 38.933117
-77.07223 38.85225
-77.029467 38.875186};
}
